package cn.com.infosec.crypto.agreement.kdf;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.crypto.DerivationFunction;
import cn.com.infosec.crypto.DerivationParameters;
import cn.com.infosec.crypto.Digest;
import cn.com.infosec.crypto.generators.KDF2BytesGenerator;
import cn.com.infosec.crypto.params.KDFParameters;

public class ECDHKEKGenerator implements DerivationFunction {
   private DerivationFunction kdf;
   private DERObjectIdentifier algorithm;
   private int keySize;
   private byte[] z;

   public ECDHKEKGenerator(Digest digest) {
      ECDHKEKGenerator var10000 = this;
      super();
      KDF2BytesGenerator var2;
      var2 = new KDF2BytesGenerator.<init>(digest);
      var10000.kdf = var2;
   }

   private byte[] integerToBytes(int keySize) {
      byte[] var2;
      byte[] var10000 = var2 = new byte[4];
      var2[0] = (byte)(keySize >> 24);
      var2[1] = (byte)(keySize >> 16);
      var2[2] = (byte)(keySize >> 8);
      var10000[3] = (byte)keySize;
      return var10000;
   }

   public void init(DerivationParameters param) {
      ECDHKEKGenerator var10000 = this;
      ECDHKEKGenerator var10001 = this;
      DHKDFParameters var2;
      this.algorithm = (var2 = (DHKDFParameters)param).getAlgorithm();
      var10001.keySize = var2.getKeySize();
      var10000.z = var2.getZ();
   }

   public Digest getDigest() {
      return this.kdf.getDigest();
   }

   public int generateBytes(byte[] out, int outOff, int len) {
      ASN1EncodableVector var4;
      ASN1EncodableVector var10002 = var4 = new ASN1EncodableVector;
      var10002.<init>();
      var10002.add(new AlgorithmIdentifier(this.algorithm, new DERNull()));
      DEROctetString var5;
      var5 = new DEROctetString.<init>(this.integerToBytes(this.keySize));
      var10002.add(new DERTaggedObject(true, 2, var5));
      this.kdf.init(new KDFParameters(this.z, (new DERSequence(var4)).getDEREncoded()));
      return this.kdf.generateBytes(out, outOff, len);
   }
}
